==> nextcloud-app-bookmarks-1%3A0.16.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/de_DE.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Lesezeichen",
    "Add a Bookmark" : "Lesezeichen hinzufügen",
    "Add folder" : "Ordner hinzufügen",
    "Select" : "Auswählen",
    "Deselect" : "Abwählen",
    "Details" : "Details",
    "Delete" : "Löschen",
    "Saved" : "Gespeichert",
    "Date added" : "Datum hinzugefügt",
    "Link" : "Link",
    "Tags" : "Schlagworte",
    "Description" : "Beschreibung",
    "No bookmarks here." : "Keine Lesezeichen vorhanden",
    "Favorites" : "Favoriten",
    "Settings" : "Einstellungen",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName} " : "Hinzufügen zu {instanceName} ",
    "Recently added" : "Vor kurzem hinzugefügt",
    "Most visited" : "Am meisten besucht",
    "View mode" : "Anzeigemodus",
    "List view" : "Listenansicht",
    "RSS Feed" : "RSS-Feed",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Alle Lesezeichen Ihres Kontos dauerhaft löschen. Es gibt kein zurück!",
    "Delete all bookmarks" : "Alle Lesezeichen löschen",
    "Open details" : "Details öffnen",
    "An error occurred while trying to save the bookmark." : "Beim Speichern des Lesezeichens ist ein Fehler aufgetreten.",
    "Error" : "Fehler",
    "Uncategorized" : "Ohne Kategorie",
    "Error parsing the import result" : "Fehler beim Analysieren des Importergebnisses",
    "Import completed successfully." : "Import erfolgreich beendet.",
    "Do you really want to delete all your bookmarks?" : "Möchtest Du wirklich das Lesezeichen löschen?",
    "Set tags" : "Schlagworte setzen",
    "Failed to import one bookmark, because: " : "Ein Lesezeichen konnte nicht importiert werden, weil:",
    "No file provided for import" : "Keine Datei zum Importieren ausgewählt",
    "Unsupported file type for import" : "Ein Import von Dateien dieses Typs wird nicht unterstützt",
    "A Bookmark manager for Nextcloud" : "Eine Lesezeichenverwaltung für Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Diese App erlaubt es Ihnen all Ihre beliebten Orte im Internet an einer Stelle zu speichern und zu verwalten. Weiter werden diese Lesezeichen mit Ihren Geräten und Browsern synchronisiert.\nSehen Sie sich auch die Liste der Clients von Drittanbietern an: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Lesezeichen hinzufügen",
    "This URL is already bookmarked! Overwrite?" : "Diese URL ist bereits als Lesezeichen gespeichert!. Überschreiben?",
    "The title of the page" : "Seitentitel",
    "The address of the page" : "Adresse der Seite",
    "Description of the page" : "Beschreibung der Seite",
    "Save" : "Speichern",
    "Previews" : "Vorschau",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Um Screenshots der  gespeicherten Seiten zu erzeugen kann die Lesezeichen-App einen externen Service verwenden.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Sie können sich entweder kostenlos unter <a href=\"http://screeenly.com\">screeenly.com</a> anmelden oder Ihren <a href=\"https://github.com/stefanzweifel/screeenly\">eigenen Server aufsetzen</a>.",
    "Screenly API URL" : "Screenly API URL",
    "Screenly API key" : "Screenly API key",
    "Bookmarks feed" : "Lesezeichen-Feed"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A0.16.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/de_DE.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Lesezeichen",
    "Add a Bookmark" : "Lesezeichen hinzufügen",
    "Add folder" : "Ordner hinzufügen",
    "Select" : "Auswählen",
    "Deselect" : "Abwählen",
    "Details" : "Details",
    "Delete" : "Löschen",
    "Saved" : "Gespeichert",
    "Date added" : "Datum hinzugefügt",
    "Link" : "Link",
    "Tags" : "Schlagworte",
    "Description" : "Beschreibung",
    "No bookmarks here." : "Keine Lesezeichen vorhanden",
    "Favorites" : "Favoriten",
    "Settings" : "Einstellungen",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName} " : "Hinzufügen zu {instanceName} ",
    "Recently added" : "Vor kurzem hinzugefügt",
    "Most visited" : "Am meisten besucht",
    "View mode" : "Anzeigemodus",
    "List view" : "Listenansicht",
    "RSS Feed" : "RSS-Feed",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Alle Lesezeichen Ihres Kontos dauerhaft löschen. Es gibt kein zurück!",
    "Delete all bookmarks" : "Alle Lesezeichen löschen",
    "Open details" : "Details öffnen",
    "An error occurred while trying to save the bookmark." : "Beim Speichern des Lesezeichens ist ein Fehler aufgetreten.",
    "Error" : "Fehler",
    "Uncategorized" : "Ohne Kategorie",
    "Error parsing the import result" : "Fehler beim Analysieren des Importergebnisses",
    "Import completed successfully." : "Import erfolgreich beendet.",
    "Do you really want to delete all your bookmarks?" : "Möchten Sie wirklich alle Lesezeichen löschen?",
    "Set tags" : "Schlagworte setzen",
    "Failed to import one bookmark, because: " : "Ein Lesezeichen konnte nicht importiert werden, weil:",
    "No file provided for import" : "Keine Datei zum Importieren ausgewählt",
    "Unsupported file type for import" : "Ein Import von Dateien dieses Typs wird nicht unterstützt",
    "A Bookmark manager for Nextcloud" : "Eine Lesezeichenverwaltung für Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Diese App erlaubt es Ihnen all Ihre beliebten Orte im Internet an einer Stelle zu speichern und zu verwalten. Weiter werden diese Lesezeichen mit Ihren Geräten und Browsern synchronisiert.\nSehen Sie sich auch die Liste der Clients von Drittanbietern an: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Lesezeichen hinzufügen",
    "This URL is already bookmarked! Overwrite?" : "Diese URL ist bereits als Lesezeichen gespeichert!. Überschreiben?",
    "The title of the page" : "Seitentitel",
    "The address of the page" : "Adresse der Seite",
    "Description of the page" : "Beschreibung der Seite",
    "Save" : "Speichern",
    "Previews" : "Vorschau",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Um Screenshots der  gespeicherten Seiten zu erzeugen kann die Lesezeichen-App einen externen Service verwenden.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Sie können sich entweder kostenlos unter <a href=\"http://screeenly.com\">screeenly.com</a> anmelden oder Ihren <a href=\"https://github.com/stefanzweifel/screeenly\">eigenen Server aufsetzen</a>.",
    "Bookmarks feed" : "Lesezeichen-Feed"
},
"nplurals=2; plural=(n != 1);");
